# DarePype
DarePype (Data Reduction Pipeline in Python) is a python framework for developing data reduction pipelines.

Read the documentation at [darepype.readthedocs.io](https://darepype.readthedocs.io).

The core package for the framework is well developped and is used for the [HAWC instrument](https://www.sofia.usra.edu/science/instruments/hawc) pipeline and the [SEO telescope](https://stoneedgeobservatory.com/) pipeline at [github/yerkesobservatory/pipeline](https://github.com/yerkesobservatory/pipeline).

## Badges
[![Build Status](https://travis-ci.org/berthoud/darepype.svg?branch=master)](https://travis-ci.org/berthoud/darepype)
